from pathlib import Path
from src.utils import load_json_file


class SettingsLoader:
    """
    A class for handling the loading

    Attributes
    ----------

    Methods
    -------
    load_settings_json(filename: str = "analysis_settings.json"):
        Loads settings from a JSON file.
    """

    def __init__(self):
        self.settings: dict[str, str] = self.load_settings_json()
        self.directory_raw_comment_data: Path = Path(
            self.settings["path_to_comment_data"]
        )
        self.directory_raw_article_data: Path = Path(
            self.settings["path_to_article_data"]
        )
        self.add_extend_article_information = self.settings[
            "flag_add_extend_article_information"
        ]
        self.add_comment_text_body = self.settings["flag_include_comments_text_body"]

    @staticmethod
    def load_settings_json(filename: Path = Path("settings.json")) -> dict[str, str]:
        """
        Function to load JSON file containing the settings to run the analysis with.
        This contains the path to the data.

        Parameters
        ----------
        filename : str
            The name of the JSON file.

        Returns
        -------
        dict[str, str]
            Returns the loaded JSON file.
        """
        data: dict[str, str] = load_json_file(filename)

        return data
