"""
The `utils.py` module provides utility functions for common operations such as loading
JSON files and saving data to CSV files.

"""

from pathlib import Path
import pandas as pd
import json


def load_json_file(file_path: Path) -> dict:
    """
    Load data from a JSON file and return it as a dictionary.

    Parameters
    ----------
    file_path : pathlib.Path
        Path object representing a JSON file path.

    Returns
    -------
    dict
        A dictionary containing the JSON data.
    """
    with file_path.open("r") as file:
        comment_data: dict = json.loads(file.read())

    return comment_data


def save_data(filepath: Path, data: pd.DataFrame) -> None:
    """
    Save data to a parquet file.

    Parameters
    ----------
    filepath : Path
        The file path (including name) of the parquet file to save the data to.
    data : pd.DataFrame
        A pandas DataFrame containing the data to be saved.

    Returns
    -------
    None
    """
    data.to_parquet(filepath)
